@@ -2,20 +2,20 @@
 #######################################################################
 """InterfaceSwitcher field
 
-$Id: interfacevocabulary.py 49056 2007-12-27 23:17:08Z cray $
+$Id: interfacevocabulary.py 51938 2008-10-23 08:22:07Z cray $
 """
 
 __author__  = "Andrey Orlov"
 __license__ = "ZPL"
-__version__ = "$Revision: 49056 $"
+__version__ = "$Revision: 51938 $"
 
 from zope.interface import implements
 from zope.interface.interfaces import IInterface
-from zope.schema.vocabulary import SimpleVocabulary
+from zope.schema.vocabulary import SimpleVocabulary,SimpleTerm
 from zope.schema.interfaces import  IContextSourceBinder
 from zope.app.zapi import getUtilitiesFor
 
-    
+
 class InterfaceVocabulary(object) :
     implements(IContextSourceBinder)
 
@@ -30,3 +30,16 @@ class InterfaceVocabulary(object) :
                     if interface.extends(self.ob.iface)],
                 key = lambda (name, interface): name)
             )
+    
+class InterfaceTitledVocabulary(InterfaceVocabulary) :
+
+    def __call__(self, object) :        
+        return SimpleVocabulary(
+            sorted(
+                [SimpleTerm(interface, name, interface.__doc__) 
+                    for (name,interface) in getUtilitiesFor(IInterface, object)
+                    if interface.extends(self.ob.iface)],
+                key = lambda x : x.token)
+            )
+
+
